==> client-java-api-9.0.2-sources.jar: io/kubernetes/client/openapi/models/NetworkingV1beta1HTTPIngressPathFluent.java <==
package io.kubernetes.client.openapi.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Boolean;

public interface NetworkingV1beta1HTTPIngressPathFluent<A extends NetworkingV1beta1HTTPIngressPathFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildBackend instead.
 * @return The buildable object.
 */
@Deprecated public NetworkingV1beta1IngressBackend getBackend();
    public NetworkingV1beta1IngressBackend buildBackend();
    public A withBackend(NetworkingV1beta1IngressBackend backend);
    public Boolean hasBackend();
    public NetworkingV1beta1HTTPIngressPathFluent.BackendNested<A> withNewBackend();
    public NetworkingV1beta1HTTPIngressPathFluent.BackendNested<A> withNewBackendLike(NetworkingV1beta1IngressBackend item);
    public NetworkingV1beta1HTTPIngressPathFluent.BackendNested<A> editBackend();
    public NetworkingV1beta1HTTPIngressPathFluent.BackendNested<A> editOrNewBackend();
    public NetworkingV1beta1HTTPIngressPathFluent.BackendNested<A> editOrNewBackendLike(NetworkingV1beta1IngressBackend item);
    public String getPath();
    public A withPath(String path);
    public Boolean hasPath();
    public A withNewPath(String arg1);
    public A withNewPath(StringBuilder arg1);
    public A withNewPath(StringBuffer arg1);

    public interface BackendNested<N> extends io.kubernetes.client.fluent.Nested<N>,NetworkingV1beta1IngressBackendFluent<NetworkingV1beta1HTTPIngressPathFluent.BackendNested<N>>{

        
    public N and();    public N endBackend();
}


}

==> client-java-api-10.0.0-sources.jar: io/kubernetes/client/openapi/models/NetworkingV1beta1HTTPIngressPathFluent.java <==
package io.kubernetes.client.openapi.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Boolean;

public interface NetworkingV1beta1HTTPIngressPathFluent<A extends NetworkingV1beta1HTTPIngressPathFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildBackend instead.
 * @return The buildable object.
 */
@Deprecated public NetworkingV1beta1IngressBackend getBackend();
    public NetworkingV1beta1IngressBackend buildBackend();
    public A withBackend(NetworkingV1beta1IngressBackend backend);
    public Boolean hasBackend();
    public NetworkingV1beta1HTTPIngressPathFluent.BackendNested<A> withNewBackend();
    public NetworkingV1beta1HTTPIngressPathFluent.BackendNested<A> withNewBackendLike(NetworkingV1beta1IngressBackend item);
    public NetworkingV1beta1HTTPIngressPathFluent.BackendNested<A> editBackend();
    public NetworkingV1beta1HTTPIngressPathFluent.BackendNested<A> editOrNewBackend();
    public NetworkingV1beta1HTTPIngressPathFluent.BackendNested<A> editOrNewBackendLike(NetworkingV1beta1IngressBackend item);
    public String getPath();
    public A withPath(String path);
    public Boolean hasPath();
    public A withNewPath(String arg1);
    public A withNewPath(StringBuilder arg1);
    public A withNewPath(StringBuffer arg1);
    public String getPathType();
    public A withPathType(String pathType);
    public Boolean hasPathType();
    public A withNewPathType(String arg1);
    public A withNewPathType(StringBuilder arg1);
    public A withNewPathType(StringBuffer arg1);

    public interface BackendNested<N> extends io.kubernetes.client.fluent.Nested<N>,NetworkingV1beta1IngressBackendFluent<NetworkingV1beta1HTTPIngressPathFluent.BackendNested<N>>{

        
    public N and();    public N endBackend();
}


}
